"use client";

import { useTranslations } from "next-intl";
import { useState } from "react";
import EmptyReviews from "./customer-reviews/empty-reviews";
import PaginationControls from "./customer-reviews/pagination-controls";
import PaginationIndicators from "./customer-reviews/pagination-indicators";
import ReviewsList from "./customer-reviews/reviews-list";

function CustomerReviews({ reviews }: { reviews: any }) {
	const t = useTranslations("Common");
	const [currentPage, setCurrentPage] = useState(0);
	const reviewsPerPage = 3; // Number of reviews to show per page

	// Calculate total pages
	const totalPages = reviews?.length ? Math.ceil(reviews.length / reviewsPerPage) : 0;

	// Navigation handlers
	const handleNextPage = () => {
		setCurrentPage((prev) => (prev + 1) % totalPages);
	};

	const handlePrevPage = () => {
		setCurrentPage((prev) => (prev - 1 + totalPages) % totalPages);
	};

	return (
		// Main container with padding and RTL direction
		<div dir="rtl" className="container mx-auto px-4 py-12 font-sans">
			{/* Header section with title and navigation */}
			<div className="flex justify-between items-center mb-8">
				<h1 className="text-2xl mt-6 font-bold text-custom-dark">{t("Customer Reviews")}</h1>
				{reviews?.length > 3 && (
					<PaginationControls
						currentPage={currentPage}
						totalPages={totalPages}
						onPageChange={setCurrentPage}
						onNextPage={handleNextPage}
						onPrevPage={handlePrevPage}
					/>
				)}
			</div>

			{reviews?.length > 0 ? (
				<>
					<ReviewsList
						reviews={reviews}
						currentPage={currentPage}
						reviewsPerPage={reviewsPerPage}
					/>

					{/* Bottom pagination indicators */}
					<PaginationIndicators
						currentPage={currentPage}
						totalPages={totalPages}
						onPageChange={setCurrentPage}
					/>
				</>
			) : (
				<EmptyReviews />
			)}
		</div>
	);
}

export default CustomerReviews;
